@@ -15,7 +15,8 @@ build_time_vars = {'ABIFLAGS': '',
  'BINDIR': '/usr/bin',
  'BINLIBDEST': '/usr/lib/python3.10',
  'BLDLIBRARY': '-L. -lpython3.10',
- 'BLDSHARED': 'gcc -shared',
+ 'BLDSHARED': 'gcc -shared -Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
+              '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
  'BUILD_GNU_TYPE': 'aarch64-unknown-linux-gnu',
@@ -23,32 +24,55 @@ build_time_vars = {'ABIFLAGS': '',
  'CC': 'gcc',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
-           '-O3 -pipe -O3 -pipe -O3 -pipe',
+           '-O3 -pipe -fstack-protector-strong -fno-plt '
+           '-fexceptions                -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+           '-Werror=format-security                -fstack-clash-protection '
+           '-ffat-lto-objects -O3 -pipe -fstack-protector-strong -fno-plt '
+           '-fexceptions                -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+           '-Werror=format-security                -fstack-clash-protection '
+           '-ffat-lto-objects -O3 -pipe -fstack-protector-strong -fno-plt '
+           '-fexceptions                -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+           '-Werror=format-security                -fstack-clash-protection '
+           '-ffat-lto-objects',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
- 'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
- 'CONFIGURE_CFLAGS': '-O3 -pipe',
- 'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
-                            '-Wno-unused-parameter '
+ 'CONFIGURE_CFLAGS': '-O3 -pipe -fstack-protector-strong -fno-plt '
+                     '-fexceptions                -Wp,-D_FORTIFY_SOURCE=2 '
+                     '-Wformat -Werror=format-security                '
+                     '-fstack-clash-protection -ffat-lto-objects',
+ 'CONFIGURE_CFLAGS_NODIST': '-fno-semantic-interposition -flto=4 '
+                            '-fuse-linker-plugin -ffat-lto-objects '
+                            '-flto-partition=none -g -std=c99 -Wextra '
+                            '-Wno-unused-result -Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
                             '-Werror=implicit-function-declaration '
                             '-fvisibility=hidden',
  'CONFIGURE_CPPFLAGS': '',
- 'CONFIGURE_LDFLAGS': '',
- 'CONFIGURE_LDFLAGS_NODIST': '',
- 'CONFIG_ARGS': "'--prefix=/usr' '--enable-shared' '--enable-ipv6' "
-                "'--enable-loadable-sqlite-extensions' '--with-computed-gotos' "
-                "'--with-dbmliborder=gdbm:ndbm' '--without-lto' "
-                "'--with-system-expat' '--with-system-ffi' "
+ 'CONFIGURE_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
+ 'CONFIGURE_LDFLAGS_NODIST': '-fno-semantic-interposition -flto=4 '
+                             '-fuse-linker-plugin -ffat-lto-objects '
+                             '-flto-partition=none -g',
+ 'CONFIG_ARGS': "'--prefix=/usr' '--enable-shared' '--enable-optimizations' "
+                "'--enable-ipv6' '--enable-loadable-sqlite-extensions' "
+                "'--with-computed-gotos' '--with-dbmliborder=gdbm:ndbm' "
+                "'--with-lto' '--with-system-expat' '--with-system-ffi' "
                 "'--with-system-libmpdec' '--with-tzpath=/usr/share/zoneinfo' "
-                "'--without-ensurepip' 'CFLAGS=-O3 -pipe'",
+                "'--without-ensurepip' 'CFLAGS=-O3 -pipe "
+                '-fstack-protector-strong -fno-plt -fexceptions                '
+                '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                '-Werror=format-security                '
+                "-fstack-clash-protection -ffat-lto-objects' "
+                "'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now' "
+                "'PROFILE_TASK=-m test -j8 --pgo-extended -x test_gdb "
+                '-u-network -x test_socket -x test_asyncio -x test_httpservers '
+                "-x test_logging -x test_multiprocessing_fork -x test_xmlrpc'",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.10',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/usr/ports/core-arm64/python3/work/src/Python-3.10.9/coverage.info',
- 'COVERAGE_REPORT': '/usr/ports/core-arm64/python3/work/src/Python-3.10.9/lcov-report',
+ 'COVERAGE_INFO': '/usr/ports/core/python3/work/src/Python-3.10.13/coverage.info',
+ 'COVERAGE_REPORT': '/usr/ports/core/python3/work/src/Python-3.10.13/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include',
@@ -537,11 +561,12 @@ build_time_vars = {'ABIFLAGS': '',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'g++ -shared',
- 'LDFLAGS': '',
- 'LDFLAGS_NODIST': '',
+ 'LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
+            '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
  'LDLIBRARY': 'libpython3.10.so',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'gcc -shared',
+ 'LDSHARED': 'gcc -shared -Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
+             '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
  'LDVERSION': '3.10',
  'LIBC': '',
  'LIBDEST': '/usr/lib/python3.10',
@@ -623,7 +648,9 @@ build_time_vars = {'ABIFLAGS': '',
  'PLATLIBDIR': 'lib',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
- 'PROFILE_TASK': '-m test --pgo --timeout=1200',
+ 'PROFILE_TASK': '-m test -j8 --pgo-extended -x test_gdb -u-network -x '
+                 'test_socket -x test_asyncio -x test_httpservers -x '
+                 'test_logging -x test_multiprocessing_fork -x test_xmlrpc',
  'PTHREAD_KEY_T_IS_COMPATIBLE_WITH_INT': 1,
  'PTHREAD_SYSTEM_SCHED_SUPPORTED': 1,
  'PURIFY': '',
@@ -641,40 +668,104 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g '
-                             '-fwrapv -O3 -Wall -O3 -pipe -O3 -pipe -O3 -pipe '
-                             '-std=c99 -Wextra -Wno-unused-result '
-                             '-Wno-unused-parameter '
+                             '-fwrapv -O3 -Wall -O3 -pipe '
+                             '-fstack-protector-strong -fno-plt '
+                             '-fexceptions                '
+                             '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                             '-Werror=format-security                '
+                             '-fstack-clash-protection -ffat-lto-objects -O3 '
+                             '-pipe -fstack-protector-strong -fno-plt '
+                             '-fexceptions                '
+                             '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                             '-Werror=format-security                '
+                             '-fstack-clash-protection -ffat-lto-objects -O3 '
+                             '-pipe -fstack-protector-strong -fno-plt '
+                             '-fexceptions                '
+                             '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                             '-Werror=format-security                '
+                             '-fstack-clash-protection -ffat-lto-objects '
+                             '-fno-semantic-interposition -flto=4 '
+                             '-fuse-linker-plugin -ffat-lto-objects '
+                             '-flto-partition=none -g -std=c99 -Wextra '
+                             '-Wno-unused-result -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Werror=implicit-function-declaration '
-                             '-fvisibility=hidden  -I./Include/internal -I. '
+                             '-fvisibility=hidden -fprofile-use '
+                             '-fprofile-correction -I./Include/internal -I. '
                              '-I./Include -fPIC -DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
-              '-O3 -pipe -O3 -pipe -O3 -pipe',
- 'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
-                     '-Wno-unused-parameter -Wno-missing-field-initializers '
+              '-O3 -pipe -fstack-protector-strong -fno-plt '
+              '-fexceptions                -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+              '-Werror=format-security                -fstack-clash-protection '
+              '-ffat-lto-objects -O3 -pipe -fstack-protector-strong -fno-plt '
+              '-fexceptions                -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+              '-Werror=format-security                -fstack-clash-protection '
+              '-ffat-lto-objects -O3 -pipe -fstack-protector-strong -fno-plt '
+              '-fexceptions                -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+              '-Werror=format-security                -fstack-clash-protection '
+              '-ffat-lto-objects',
+ 'PY_CFLAGS_NODIST': '-fno-semantic-interposition -flto=4 -fuse-linker-plugin '
+                     '-ffat-lto-objects -flto-partition=none -g -std=c99 '
+                     '-Wextra -Wno-unused-result -Wno-unused-parameter '
+                     '-Wno-missing-field-initializers '
                      '-Werror=implicit-function-declaration '
-                     '-fvisibility=hidden  -I./Include/internal',
+                     '-fvisibility=hidden -fprofile-use -fprofile-correction '
+                     '-I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 '
-                   '-Wall -O3 -pipe -O3 -pipe -O3 -pipe -std=c99 -Wextra '
+                   '-Wall -O3 -pipe -fstack-protector-strong -fno-plt '
+                   '-fexceptions                -Wp,-D_FORTIFY_SOURCE=2 '
+                   '-Wformat -Werror=format-security                '
+                   '-fstack-clash-protection -ffat-lto-objects -O3 -pipe '
+                   '-fstack-protector-strong -fno-plt '
+                   '-fexceptions                -Wp,-D_FORTIFY_SOURCE=2 '
+                   '-Wformat -Werror=format-security                '
+                   '-fstack-clash-protection -ffat-lto-objects -O3 -pipe '
+                   '-fstack-protector-strong -fno-plt '
+                   '-fexceptions                -Wp,-D_FORTIFY_SOURCE=2 '
+                   '-Wformat -Werror=format-security                '
+                   '-fstack-clash-protection -ffat-lto-objects '
+                   '-fno-semantic-interposition -flto=4 -fuse-linker-plugin '
+                   '-ffat-lto-objects -flto-partition=none -g -std=c99 -Wextra '
                    '-Wno-unused-result -Wno-unused-parameter '
                    '-Wno-missing-field-initializers '
-                   '-Werror=implicit-function-declaration -fvisibility=hidden  '
-                   '-I./Include/internal -I. -I./Include -fPIC -DPy_BUILD_CORE',
- 'PY_CORE_LDFLAGS': '',
+                   '-Werror=implicit-function-declaration -fvisibility=hidden '
+                   '-fprofile-use -fprofile-correction -I./Include/internal '
+                   '-I. -I./Include -fPIC -DPy_BUILD_CORE',
+ 'PY_CORE_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
+                    '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
+                    '-fno-semantic-interposition -flto=4 -fuse-linker-plugin '
+                    '-ffat-lto-objects -flto-partition=none -g',
  'PY_CPPFLAGS': '-I. -I./Include',
  'PY_ENABLE_SHARED': 1,
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_LDFLAGS': '',
- 'PY_LDFLAGS_NODIST': '',
+ 'PY_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
+               '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
+ 'PY_LDFLAGS_NODIST': '-fno-semantic-interposition -flto=4 -fuse-linker-plugin '
+                      '-ffat-lto-objects -flto-partition=none -g',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv '
-                        '-O3 -Wall -O3 -pipe -O3 -pipe -O3 -pipe -std=c99 '
-                        '-Wextra -Wno-unused-result -Wno-unused-parameter '
+                        '-O3 -Wall -O3 -pipe -fstack-protector-strong -fno-plt '
+                        '-fexceptions                -Wp,-D_FORTIFY_SOURCE=2 '
+                        '-Wformat -Werror=format-security                '
+                        '-fstack-clash-protection -ffat-lto-objects -O3 -pipe '
+                        '-fstack-protector-strong -fno-plt '
+                        '-fexceptions                -Wp,-D_FORTIFY_SOURCE=2 '
+                        '-Wformat -Werror=format-security                '
+                        '-fstack-clash-protection -ffat-lto-objects -O3 -pipe '
+                        '-fstack-protector-strong -fno-plt '
+                        '-fexceptions                -Wp,-D_FORTIFY_SOURCE=2 '
+                        '-Wformat -Werror=format-security                '
+                        '-fstack-clash-protection -ffat-lto-objects '
+                        '-fno-semantic-interposition -flto=4 '
+                        '-fuse-linker-plugin -ffat-lto-objects '
+                        '-flto-partition=none -g -std=c99 -Wextra '
+                        '-Wno-unused-result -Wno-unused-parameter '
                         '-Wno-missing-field-initializers '
                         '-Werror=implicit-function-declaration '
-                        '-fvisibility=hidden  -I./Include/internal -I. '
+                        '-fvisibility=hidden -fprofile-use '
+                        '-fprofile-correction -I./Include/internal -I. '
                         '-I./Include -fPIC',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
@@ -684,7 +775,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/ports/core-arm64/python3/work/src/Python-3.10.9',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/ports/core/python3/work/src/Python-3.10.13',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SHELL': '/bin/sh',
@@ -726,10 +817,10 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/ports/core-arm64/python3/work/src/Python-3.10.9 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/ports/core/python3/work/src/Python-3.10.13 '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/usr/ports/core-arm64/python3/work/src/Python-3.10.9 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/usr/ports/core/python3/work/src/Python-3.10.13 '
                './python ./Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'ctypes/test \\',
  'TESTTIMEOUT': 1200,
@@ -757,8 +848,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/usr/ports/core-arm64/python3/work/src/Python-3.10.9',
- 'abs_srcdir': '/usr/ports/core-arm64/python3/work/src/Python-3.10.9',
+ 'abs_builddir': '/usr/ports/core/python3/work/src/Python-3.10.13',
+ 'abs_srcdir': '/usr/ports/core/python3/work/src/Python-3.10.13',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
